remove_file_if_exists

Function remove_file_if_exists 

pub fn remove_file_if_exists(path: impl AsRef<Path>) -> Result<()>
Removes a file at the given path, ignoring the error if the file does not exist (ErrorKind::NotFound).